@@ -413,7 +413,7 @@ class vertice_modifier:
                 sor_sp=i[np.lexsort((i[:,1].round(decimals=4),i[:,0].round(decimals=4)))].copy()
                 sor_arr_rec.append(sor_sp)
 
-                meds.append(sor_sp[int (self.resolution[1, 0]//2 + (sor_sp)//2)])
+                meds.append(sor_sp[int (self.resolution[1, 0]//2 + len(sor_sp)//2)])
 
             meds = np.split (np.array(meds), self.n_iterations)
             reconstructed_ar = list(self.chunks(sor_arr_rec, int (len(sor_arr_rec)/self.n_iterations)))
